#!../venv/bin/python3.7
import sys
from PyQt5.QtWidgets import QApplication

from config import Config

from gui.mainwindow import MainWindow

from controller.analysecontroller import AnalyseController

from dataprovider.conductcalibprovider import ConductCalibProvider
from dataprovider.exploprovider import ExploProvider
from dataprovider.icbktransitionprovider import IcbktransitionProvider
from dataprovider.picarroprovider import PicarroProvider

from uim.analyseuim import AnalyseUim
from uim.conductcalibuim import ConductCalibUim
from uim.datconvertuim import DatconvertUim
from uim.explouim import ExploUim
from uim.icbktransitionuim import IcbktransitionUim
from uim.picarrocalibuim import PicarroCalibUim
from uim.picarrocorrectionuim import PicarroCorrectionUim
from uim.picarroinjectionuim import PicarroInjectionUim
from uim.pumpcalibuim import PumpCalibUim

########################################################################################################################
# CONFIG
########################################################################################################################
config = Config("settings.ini")

########################################################################################################################
# WINDOWS
########################################################################################################################

app = QApplication(sys.argv)
main_window = MainWindow()
main_window_ui = main_window.main_ui

########################################################################################################################
# DATA PROVIDERS
########################################################################################################################
analyse_ctrl = AnalyseController()
conduct_prvd = ConductCalibProvider()
explo_prvd = ExploProvider()
icbktransition_prvd = IcbktransitionProvider(explo_prvd)
picarro_prvd = PicarroProvider()

########################################################################################################################
# GUI MANAGERS
########################################################################################################################
analys_uim = AnalyseUim(analyse_ctrl, main_window_ui, config, main_window)
conductcalib_uim = ConductCalibUim(conduct_prvd, main_window_ui, config)
datconvert_uim = DatconvertUim(picarro_prvd, main_window.datconvert_dialog.ui, config)
explo_uim = ExploUim(
    explo_prvd, icbktransition_prvd, main_window_ui, config, main_window.stab_dialog
)
icbktransition_uim = IcbktransitionUim(
    icbktransition_prvd,
    explo_uim,
    main_window_ui,
    config,
    main_window.icbktransition_dialog,
)
picarro_uim = PicarroCalibUim(picarro_prvd, main_window_ui, config)
picarro_injection_uim = PicarroInjectionUim(picarro_uim)
picarro_correction_uim = PicarroCorrectionUim(picarro_uim)
pump_uim = PumpCalibUim(main_window_ui, config)

########################################################################################################################
# LAUNCH APPLICATION
########################################################################################################################

main_window.show()
sys.exit(app.exec_())
